@@ -18,12 +18,15 @@ controlnet_pose_model_list = [
     "thibaud/controlnet-sd21-openpose-diffusers",
 ]
 
-
 controlnet_hed_model_list = [
+    "lllyasviel/sd-controlnet-hed",
+    "thibaud/controlnet-sd21-hed-diffusers",
+]
+
+controlnet_scribble_model_list = [
     "lllyasviel/sd-controlnet-scribble",
     "thibaud/controlnet-sd21-scribble-diffusers",
 ]
-
 stable_inpiant_model_list = [
     "stabilityai/stable-diffusion-2-inpainting",
     "runwayml/stable-diffusion-inpainting",
